import Taro, { Component } from '@tarojs/taro';
import ListView from '@components/ListView'
import { connect } from '@tarojs/redux'
import './index.scss'
import { getConsulantVisitRecord, getMoreVisitRecord } from '@services/person'
import { savePoint, updatePoint } from '@services/common'
import dayjs from 'dayjs';

@connect(state => state.user)
export default class Person extends Component {
  config = {
    navigationBarTitleText: '访客信息'
  }

  state = {
    popVisible: false,
    recordId: undefined, // 埋点ID
    recordList: [],
    hasMore: true,
    isEmpty: false,
    pageIndex: 1,
    moreRecord: []
  }

  componentWillMount() {

    savePoint({
      event: 'list',
      eventType: 'activity',
      propertyName: '访客信息',
      data: '{}'
    }).then(res => {
      this.setState({
        recordId: res.recordId
      })
      console.log('访客信息')
    })
  }
  componentWillUnmount() {
    const { recordId } = this.state
    recordId && updatePoint(recordId)
  }

  handleMaskClose() {
    this.setState({
      popVisible: false,
    })
  }
  componentDidShow() {
    Taro.showLoading()
    this.loadList(1)

  }
  loadList(pageNumber) {
    console.log(this.props, "this.props")
    const { userInfo: { person } } = this.props
    const payload = {
      userId: person.userId,
      pageNumber,
      pageSize: 5
    }
    getConsulantVisitRecord(payload).then(res => {
      const { records, list, total, current, pages } = res || {}
      const _list = records || list || []
      const newList = current <= 1 ? _list : this.state.recordList.concat(_list)
      this.setState({
        recordList: newList,
        isEmpty: total == 0 || !res,
        hasMore: current < pages,
        pageIndex: current >= pages ? pages : current
      })
      Taro.hideLoading()
    })
  }
  onScrollToLower = async (fn) => {
    const { pageIndex } = this.state;
    this.loadList(pageIndex + 1)
    fn && fn();
  }
  onPullDownRefresh = (rest) => {
    // debugger
    if (this.refreshing) return
    this.refreshing = true
    this.loadList(1)
    rest && rest()
    this.refreshing = false
  }


  showActivityList(item) {
    Taro.showLoading()
    this.setState({
      popVisible: true,
    })

    const { userInfo: { person } } = this.props
    const payload = {
      userId: person.userId,
      personId: item.personId,
    }
    getMoreVisitRecord(payload).then(res => {
      Taro.hideLoading()
      this.setState({
        moreRecord: res.records || []
      })

    }).catch(err => {
      console.log(err, "获取更多访客信息err")
      Taro.hideLoading()
    })
  }
  handleChatClick(item, e) {
    e.stopPropagation()
    const { userInfo: { person: { personId, nickname, name } } } = this.props
    Taro.navigateTo({
      url: `/pages/im/index?sendId=${personId}&sendName=${encodeURIComponent(name || nickname)}&receiverId=${item.personId}&receiverName=${encodeURIComponent(item.userName)}`
    })
  }
  renderPop() {
    const { moreRecord } = this.state
    return (
      <View className="pop-box">
        <View className="content">
          <Icon className="iconfont close icon-buoumaotubiao20" onClick={this.handleMaskClose}></Icon>
          <View className="scroll-con">
            {
              moreRecord.map(item => (
                <View className="activity-item">
                  <View className="name">{item.activityName || '　'}</View>
                  <View className="time">{`${dayjs(item.createDate).format('YYYY-MM-DD HH:mm:ss')}`}</View>
                </View>
              ))
            }
          </View>
        </View>
      </View>
    )
  }
  render() {
    const { popVisible, isEmpty, hasMore, recordList } = this.state
    return (
      <Block>
        {popVisible && this.renderPop()}

        <ListView
          className="wrap"
          needInit
          isEmpty={isEmpty}
          emptyText="暂无访客信息~"
          hasMore={hasMore}
          onPullDownRefresh={fn => this.onPullDownRefresh(fn)}
          onScrollToLower={fn => this.onScrollToLower(fn)}
        >
          <View className='access-page'>

            {
              recordList.map(item => (
                <View className='item' key={item + 'more'}>
                  {item.myCustomer == 1 && <View className="tag">我的客户</View>}
                  <Image className="touxiang" src={require('@assets/default-avatar.png')}></Image>
                  <View className="info-top">
                    <View className="name">{item.userName || '　'}</View>
                    <View style="display: flex;align-items: center;" onClick={this.handleChatClick.bind(this, item)}><Image className="goutong-icon" src={require('@assets/person/zixun.png')}></Image><Text className="goutong">在线沟通</Text></View>
                  </View>
                  <View className="activity-name" onClick={this.showActivityList.bind(this, item)}>
                    {item.activityName || '　'}
                  </View>
                  <Text className="right-icon"></Text>
                  <View className="activity-time">
                    {`${dayjs(item.createDate).format('YYYY-MM-DD HH:mm:ss')}`}
                  </View>
                </View>
              ))
            }
          </View>
        </ListView>
      </Block >
    )
  }
}
